#
# spec file for package perl-YAML-Tiny
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name YAML-Tiny
Name:           perl-YAML-Tiny
Version:        1.760.0
Release:        1.3
# 1.76 -> normalize -> 1.760.0
%define cpan_version 1.76
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Read/Write YAML files with as little code as possible
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/E/ET/ETHER/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(File::Temp) >= 0.19
BuildRequires:  perl(JSON::PP)
BuildRequires:  perl(Test::More) >= 0.88
Provides:       perl(YAML::Tiny) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
*YAML::Tiny* is a perl class for reading and writing YAML-style files,
written with as little code as possible, reducing load time and memory
overhead.

Most of the time it is accepted that Perl applications use a lot of memory
and modules. The *::Tiny* family of modules is specifically intended to
provide an ultralight and zero-dependency alternative to many more-thorough
standard modules.

This module is primarily for reading human-written files (like simple
config files) and generating very simple human-readable files. Note that I
said *human-readable* and not *geek-readable*. The sort of files that your
average manager or secretary should be able to look at and make sense of.

YAML::Tiny does not generate comments, it won't necessarily preserve the
order of your hashes, and it will normalise if reading in and writing out
again.

It only supports a very basic subset of the full YAML specification.

Usage is targeted at files like Perl's META.yml, for which a small and
easily-embeddable module is extremely attractive.

Features will only be added if they are human readable, and can be written
in a few lines of code. Please don't be offended if your request is
refused. Someone has to draw the line, and for YAML::Tiny that someone is
me.

If you need something with more power move up to YAML (7 megabytes of
memory overhead) or YAML::XS (6 megabytes memory overhead and requires a C
compiler).

To restate, YAML::Tiny does *not* preserve your comments, whitespace, or
the order of your YAML data. But it should round-trip from Perl structure
to file and back again just fine.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING README
%license LICENSE

%changelog
* Tue Dec 17 2024 Tina Müller <timueller+perl@suse.de>
- updated to 1.760.0 (1.76)
  see /usr/share/doc/packages/perl-YAML-Tiny/Changes
  1.76    2024-12-16 18:59:46Z
    [FIXED]
  - revert change from #60: "yes", "y" etc are not actually booleans.
    (see issue #66).
  1.75    2024-12-15 21:24:54Z
    [FIXED]
  - fixed regression in %%QUOTE (Nathan Monfils, PR#60) [later reverted
    in release 1.76, see above)
  - fix version comparison logic for forward compatibility (BooK, PR#63)
* Fri Mar 24 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.74
  see /usr/share/doc/packages/perl-YAML-Tiny/Changes
  1.74    2023-03-23 03:19:08Z
    [FIXED]
  - a few documentation tweaks (thanks, Giovanni Los and Richlv!)
* Thu Feb 22 2018 coolo@suse.com
- updated to 1.73
  see /usr/share/doc/packages/perl-YAML-Tiny/Changes
  1.73    2018-02-21 21:07:59Z
  - shipping 1.72 as stable, with no changes.
  1.72    2017-02-12 23:17:26Z (TRIAL RELEASE)
    [FIXED]
  - fix compatibility with Test::Builder 0.94 in test shim
  1.71    2017-02-04 05:44:07Z (TRIAL RELEASE)
    [FIXED]
  - Perform correct stripping of leading white space in literal/folded
    text blocks (Flavio Poletti, GitHub #44, fixes RT#56045).
* Tue Feb 14 2017 coolo@suse.com
- updated to 1.70
  see /usr/share/doc/packages/perl-YAML-Tiny/Changes
  1.70    2017-01-22 08:59:54Z
    [FIXED]
  - Some errors writing to a file were incorrectly reported.
* Tue Jul 28 2015 coolo@suse.com
- updated to 1.69
  see /usr/share/doc/packages/perl-YAML-Tiny/Changes
* Wed May 13 2015 coolo@suse.com
- updated to 1.67
  see /usr/share/doc/packages/perl-YAML-Tiny/Changes
  1.67      2015-05-12 00:10:24Z
    [FIXED]
  - instead of erroring on duplicate keys found in a hash (introduced in
    version 1.63), now we only warn. This fixes an issue in Strawberry Perl
    (via CPAN::Meta::YAML) when parsing a configuration file.
    [CHANGED]
  - Updated File::Temp test prereq to 0.19 for 'newdir'
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.66
  see /usr/share/doc/packages/perl-YAML-Tiny/Changes
  1.66      2015-03-16 22:26:30Z
    [CHANGED]
  - removed bundled Test::TempDir::Tiny to rely on File::Temp
    for temporary directories during testing
  1.65      2015-03-13 23:02:34Z
    [CHANGED]
  - artifacts left behind from testing are now cleaned up (GH#34)
  1.64      2014-10-08 02:56:30Z
    [CHANGED]
  - remove silencing of any errors encountered while loading
    Scalar::Util (GH#33, Graham Knop)
  - now using JSON::MaybeXS in tests instead of JSON.pm
  1.63      2014-06-11 21:58:18Z
    [FIXED]
  - incorrect error messages fixed, when $@ is clobbered when Carp
    wasn't loaded (GH#30, GH#31, Hilko Bengen)
    [CHANGED]
  - now checking for, and erroring on, duplicate keys found in a hash
    (GH#32, Hilko Bengen)
  1.62      2014-03-16 12:28:44Z
    [FIXED]
  - fix handling of trailing colon in key name (RT#92916, H.Merijn
    Brand)
  1.61      2014-02-24 16:59:49Z
    [FIXED]
  - fixed a test for VMS (RT#93297, Craig Berry)
  1.60      2014-02-13 20:31:56Z
  - shipping 1.59 as stable, with no changes.
  1.59      2014-02-06 03:10:35Z (TRIAL RELEASE)
    [CHANGED]
  - numeric values are now quoted whenever they've been used as a string
    (fixes inconsistent behaviour seen with numeric values, due to
    differences between the XS and pure-perl variants of Data::Dumper).
    (github issue #24)
  - numeric hash keys are now always quoted.
* Sun Feb  9 2014 coolo@suse.com
- updated to 1.58
    [INCOMPATIBLE CHANGE]
  - 1.57 omitted a change entry for the following change:
  - Previously, YAML::Tiny was sloppy about file encodings.  It is
    now strict.  The 'read' method and 'LoadFile' function expect
    UTF-8 encoded files.  The 'write' method and 'DumpFile' function
    produce UTF-8 encoded files.  The 'read_string' and
    'write_string' methods and the 'Load' and 'Dump' functions
    expect or generate (decoded) character data.
  - Previously, some errors would throw exceptions and some would
    return the error condition in $YAML::Tiny::errstr.  Now all
    errors throw exceptions.  Use of $errstr and the errstr method
    are deprecated. (David Golden)
    [FIXED]
  - Fixed write method to encode YAML file with UTF-8 (David Golden)
  - Improved SYNOPSIS and documentation of new (David Golden)
    [TESTING]
  - Tests have been cleaned up and reorganized.  Test coverage
    has been significnatly improved. (Ingy döt Net, David Golden,
    Jim Keenan, Karen Etheridge)
* Fri Oct  4 2013 coolo@suse.com
- updated to 1.56
  - read_string documentation error fixed (RT#74409, thanks Tim Heaney!)
  - re-release with fixed compile test
  - again packaging with ExtUtils::MakeMaker
  - convert to Dist::Zilla
  - Updated format to conform to CPAN::Changes::Spec
  - really fixed metadata
  - updated repository metadata to reflect move to github
* Wed May 23 2012 coolo@suse.com
- updated to 1.51
  - The fix described in 1.48 was incorrect. Removing an additional
    if $@ to fix it properly.
  - Make the Scalar::Util version check resistant to bugs caused by
    development versions.
* Fri Nov 18 2011 coolo@suse.com
- update to 1.50
  - Major bug fix, all code that writes arbitrary data should upgrade.
  - Simple scalars with no whitespace but ending in a colon like ABC: were
    not being quoted, which results in the parser confusing it with a
    mapping key and crashing.
  - No functional changes.
  - Don't depend on the YAML modules in RELEASE_TESTING, as it can
    pollute the advisory META.yml.
* Mon Apr  4 2011 coolo@novell.com
- updated to 1.48
  - Fix to the refaddr compatibility where Scalar::Util is installed
    but is older than 1.18.
  - No functional changes
  - Only depend on the YAML implementations when we are release testing
  - No functional changes
  - Moving to a production release now CPAN Testers is green again
  - Adding experimental support for exception->errstr conversion
  - Updating test suite yaml_error to not expect exceptions
  - Added support for trailing line comments (INGY)
  - Added checks for some characters that are illegal or reserved
    in plain scalars (INGY)
  - Minor cleaning up of some out of date POD (ADAMK)
  - Updated AUTOMATED_TESTING dependencies to new versions (ADAMK)
* Thu Dec  2 2010 seife@opensuse.org
- add perl-macros as requires (for perl_requires macro)
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Thu Aug 26 2010 pascal.bleser@opensuse.org
- initial package (1.44)
